import './assets/main.css';

import 'virtual:uno.css';

import { createHead } from '@unhead/vue';
import piniaPluginPersistedstate from 'pinia-plugin-persistedstate';
import { createI18n } from 'vue-i18n';

import { DataLoaderPlugin } from 'unplugin-vue-router/data-loaders';
import App from './App.vue';
import { router } from './router';

async function init() {
  if (import.meta.env.MODE === 'development' || 1 === 1) {
    // TODO: https://github.com/hu3dao/vite-plugin-debug/
    // https://eruda.liriliri.io/zh/docs/#快速上手
    await import('eruda').then(({ default: eruda }) => {
      eruda.init({
        defaults: {
          transparency: 0.9,
        },
      });
      // eruda.show();
    });
  }

  const app = createApp(App)
    .use(createHead())
    .use(createPinia().use(piniaPluginPersistedstate))
    // Register the plugin before the router
    .use(DataLoaderPlugin, { router })
    // adding the router will trigger the initial navigation
    .use(router)
    .use(
      createI18n({
        locale: 'zh_CN', // 默认显示语言
        fallbackLocale: 'zh_CN',
        messages: {
          en_US: {
            message: {
              hello: 'hello',
            },
          },
          zh_CN: {
            message: {
              hello: '你好',
            },
          },
        },
      }),
    );
  app.config.globalProperties.$__DEV__ = $__DEV__;
  app.mount('#app');
}

init();
